@@ -1,7 +1,6 @@
 import importlib
 import inspect
 import times
-from collections import namedtuple
 from uuid import uuid4
 from cPickle import loads, dumps, UnpicklingError
 from .local import LocalStack
@@ -257,7 +256,7 @@ class Job(object):
         """
         key = self.key
         obj = self.connection.hgetall(key)
-        if not obj:
+        if len(obj) == 0:
             raise NoSuchJobError('No such job: %s' % (key,))
 
         def to_date(date_str):
@@ -266,7 +265,11 @@ class Job(object):
             else:
                 return times.to_universal(date_str)
 
-        self.data = obj.get('data')
+        try:
+            self.data = obj['data']
+        except KeyError:
+            raise NoSuchJobError('Unexpected job format: {0}'.format(obj))
+
         try:
             self._func_name, self._instance, self._args, self._kwargs = unpickle(self.data)
         except UnpickleError:
@@ -289,7 +292,7 @@ class Job(object):
         key = self.key
 
         obj = {}
-        obj['created_at'] = times.format(self.created_at, 'UTC')
+        obj['created_at'] = times.format(self.created_at or times.now(), 'UTC')
 
         if self.func_name is not None:
             obj['data'] = dumps(self.job_tuple)
