@@ -3,6 +3,9 @@ This file contains all jobs that are used in tests.  Each of these test
 fixtures has a slighty different characteristics.
 """
 import time
+from rq import Connection
+from rq.decorators import job
+from rq import get_current_job
 
 
 def say_hello(name=None):
@@ -41,10 +44,25 @@ def create_file_after_timeout(path, timeout):
     create_file(path)
 
 
+def access_self():
+    job = get_current_job()
+    return job.id
+
+
 class Calculator(object):
     """Test instance methods."""
     def __init__(self, denominator):
         self.denominator = denominator
 
-    def calculate(x, y):
+    def calculate(self, x, y):
         return x * y / self.denominator
+
+
+with Connection():
+    @job(queue='default')
+    def decorated_job(x, y):
+        return x + y
+
+
+def long_running_job():
+    time.sleep(10)
